/***
 * Fractal ADL Parser
 * Copyright (C) 2002-2006 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Eric Bruneton
 *
 * Contributor: Philippe Merle, Matthieu Leclercq
 *
 * ---------------------------------------------------------------------------
 * $Id: ADLException.java 3624 2007-07-24 14:50:38Z apace $
 * ---------------------------------------------------------------------------
 */

package org.objectweb.fractal.adl;

/**
 * Thrown when an error occurs during the analysis of an ADL definition.
 */

public class ADLException extends Exception {

  private final Node src;

  /**
   * Constructs a new {@link ADLException}.
   * 
   * @param msg a detail message.
   */

  public ADLException(final String msg) {
    super(msg);
    src = null;
  }

  /**
   * Constructs a new {@link ADLException}.
   * 
   * @param msg a detail message.
   * @param src where the error is located.
   */

  public ADLException(final String msg, final Node src) {
    super(msg);
    this.src = src;
  }

  /**
   * Constructs a new {@link ADLException}.
   * 
   * @param msg a detail message.
   * @param e the exception that caused this exception.
   */

  public ADLException(final String msg, final Exception e) {
    super(msg, e);
    src = null;
  }

  /**
   * Constructs a new {@link ADLException}.
   * 
   * @param msg a detail message.
   * @param src where the error is located.
   * @param e the exception that caused this exception.
   */

  public ADLException(final String msg, final Node src, final Exception e) {
    super(msg, e);
    this.src = src;
  }

  /**
   * @return the source node of the error. May be <code>null</code>.
   */
  public Node getSrc() {
    return src;
  }

  @Override
  public String getMessage() {
    return (src == null) ? super.getMessage() : super.getMessage() + " ("
        + src.astGetSource() + ")";
  }
}
